`.rcsetup` removals
~~~~~~~~~~~~~~~~~~~
The following functions in `matplotlib.rcsetup` have been removed:

- ``validate_path_exists`` - use `os.path.exists` instead.
- ``update_savefig_format`` - this just replaced ``'auto'`` with ``'png'``.
- ``validate_animation_writer_path``.

Changes to valid rcParams
~~~~~~~~~~~~~~~~~~~~~~~~~
The following rcParam values are no longer valid:

- Setting :rc:`savefig.format` to ``"auto"`` - use ``"png"`` instead.
- Seeting :rc:`boxplot.whiskers` to ``"range"`` - set it to ``0, 100`` instead.
- Setting :rc:`text.hinting` to `False` or `True` - set it to ``"auto"`` or ``"none"`` respectively.
